#
# spec file for package gerbv
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gerbv
%define libname lib%{name}
Version:        2.10.0
Release:        1.5
%define somajor 1
Summary:        Gerber File Viewer that supports the RS-274X Standard
License:        GPL-2.0-only
Group:          Productivity/Scientific/Electronics
URL:            http://gerbv.geda-project.org/
Source0:        https://github.com/gerbv/gerbv/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  opensp
BuildRequires:  pkgconfig
BuildRequires:  po4a
BuildRequires:  update-desktop-files

%description
Gerber Viewer (gerbv) is a viewer for Gerber files. Gerber files are
generated from PCB CAD system and sent to PCB manufacturers as basis
for the manufacturing process. The standard supported by gerbv is
RS-274X. The basic difference between RS-274D (the old standard) and
RS-274X is basically the addition of apertures in RS-274X. It might be
possible to make an RS-274X file out of an RS-274D file and an
aperture list.

%package -n     %{libname}%{somajor}
Summary:        Gerber File Viewer library
Group:          System/Libraries

%description -n %{libname}%{somajor}
Gerbv library , allows developers to include parsing, editing, exporting,
rendering of Gerber files into other programs.

%package        devel
Summary:        Gerber File Viewer that supports the RS-274X Standard
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{somajor} = %{version}
Requires:       gtk2-devel
Requires:       libpng-devel

%description    devel
This package contains development files for developing applications
that use gerbv library.

%prep
%autosetup -p1

%build
./autogen.sh
%configure  \
            --disable-static \
            --enable-unit-mm \
            --disable-update-desktop-database

%make_build

%install
%make_install
%suse_update_desktop_file -r %{name} Education Engineering
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

#move translated man page
mkdir -p %{buildroot}/%{_mandir}/ru/man1
mv %{buildroot}/%{_mandir}/man1/%{name}.ru.1 %{buildroot}/%{_mandir}/ru/man1/%{name}.1

%find_lang %{name}

%post -n %{libname}%{somajor} -p /sbin/ldconfig

%postun -n %{libname}%{somajor} -p /sbin/ldconfig

%files -f %{name}.lang
%license COPYING
%doc NEWS README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*
%{_mandir}/*/man1/%{name}*
%{_datadir}/%{name}/
%{_datadir}/icons/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.geda-user.%{name}.gschema.xml

%files -n %{libname}%{somajor}
%{_libdir}/%{libname}.so.%{somajor}*

%files devel
%{_includedir}/*
%{_libdir}/%{libname}.so
%{_libdir}/pkgconfig/%{libname}.pc

%changelog
* Fri Nov 24 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 2.10.0:
  * Security CVE-2023-4508: Out-of-bounds memory access of filename
  * Japanese Language File (PR#183)
  * Fix crash Edit-file-format dialog (PR#181)
  * Allow gerbv foo.gvp to act like gerbv -p foo.gvp was specified
    (PR#184)
  * Fix Translation and Scale are not editable in Edit-layer dialog
    (PR#182)
  * Increase maximum zooming level (PR#186)
  * Recommend a way of reporting security issues (PR#193)
- Update to 2.9.8:
  * Using floating point math for arcs (PR#173)
  * Bump APERTURE_PARAMETERS_MAX to 10006 in order to comply with
    Gerber specification revision 2021.02 (PR#172)
  * Recognize empty drill files (PR#170)
- Update to 2.9.7:
  * The BUGS file now references GitHub instead of listing the
    known issues for reach release (PR#132)
* Mon Jan  9 2023 Dirk Müller <dmueller@suse.com>
- update to 2.9.6:
  * Turn off autodetect after FILE_FORMAT
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.9.5:
  * Replaced — with - to fix charset issue in gerbv --version on wine
  * Check for NULL schema source default
  * Changed TinySCHEME version notice from 1.34 to 1.35
  * Fix draw.h include guard (PR#141 by @ooxi)
  * Replaced — with - to fix charset issue in gerbv --version on wine
* Thu Nov 17 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.9.4
  * Fix rotation
  * libgerbv: Free the memory allocated in aperture macro comments
  * Fix CVE-2021-40400: Gerbv RS-274X aperture macro outline primitive out-of-bounds read vulnerability
  * Fix CVE-2021-40403: Gerbv pick-and-place rotation parsing use of uninitialized variable vulnerability
  * Fix CVE-2021-40401: Gerbv RS-274X aperture definition tokenization use-after-free vulnerability
  * Emit warning when G04 includes a CR or LF
  * Support spaces in excellon XY drill lines
  * Add support for Altium-style FILE_FORMAT comments
* Wed May  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Change the source URL
- Update to 2.8.2. Changes since 2.7.0:
  * Fix CVE-2021-40393: RS-274X format aperture macro variables
    out-of-bounds write vulnerability (boo#1194035)
  * Adjust autotool related files due warnings by autoconf
  * Fix CVE-2021-40391: Gerbv drill format T-code tool number
    out-of-bounds write vulnerability (boo#1192949)
  * Fix double-freeing memory
  * Fix casting pointer to different size integer
  * Fix crash when opening/saving files
- Drop patch, now upstream:
  * 0001-Fix-enum-declarations.patch
* Tue Jan 12 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix duplicate symbol error due to wrong syntax in declaration:
  * 0001-Fix-enum-declarations.patch
* Mon Mar 25 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use correct tarball from upstream
- Remove unused cruft from the specfile
* Wed Feb 27 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2.7.0
- Translations restored
- Patches:
  * gerbv-2.6.1-undefined-symbols.patch upstreamed
  * gerbv-fix-install-sh-call.patch upstreamed
  * gerbv-2.6.1-no-translation.patch upstreamed
  * gerbv-no-build-time.patch removed, build date/time is now set
    by OBS
* Tue Mar  3 2015 dev@stellardeath.org
- Backport commits 55e4460 and dd8f9fa from upstream that cures
  the problem of an undefined symbol "screen" when using gerbv as
  a library
  * gerbv-2.6.1-undefined-symbols.patch
* Tue Mar  3 2015 dmitry_r@opensuse.org
- Fix desktop menu categories
* Tue Oct  7 2014 dmitry_r@opensuse.org
- Fix build with automake 1.14
  * gerbv-fix-install-sh-call.patch
* Tue Jul 23 2013 dmitry_r@opensuse.org
- Update to version 2.6.1
  * Localization support
- Disable localization due to missed files
  * gerbv-2.6.1-no-translation.patch
* Thu Jan  3 2013 dmitry_r@opensuse.org
- Delete guile from requires
- Delete compilation time from binary
  * gerbv-no-build-time.patch
* Wed Dec 26 2012 dmitry_r@opensuse.org
- fix summary
* Tue Dec 25 2012 dmitry_r@opensuse.org
- spec file cleanup
- split libgerbv to separate package
* Tue Dec 27 2011 werner.ho@gmx.de
- new version 2.6.0
* Sat Nov 19 2011 werner.ho@gmx.de
- new version 2.5.0
- build fixes for openSUSE 12.1
* Sat Mar  6 2010 werner.ho@gmx.de
- new version 2.4.0
* Sun Oct 11 2009 werner.ho@gmx.de
- new version 2.3.0
* Fri Feb  6 2009 werner.ho@gmx.de
- new version 2.2.0
* Sat Dec 20 2008 werner.ho@gmx.de
- fixed desktop integration of openSUSE 11.1
- directory fixes
- call /sbin/ldconfig
* Sun Sep 21 2008 werner.ho@gmx.de
- new version 2.1.0
- removed support for older distributions
- created additional devel package
* Mon Mar 24 2008 werner.ho@gmx.de
- fixed desktop integration
* Tue Mar  4 2008 werner.ho@gmx.de
- new version 2.0.1
- desktop integration
* Sun Jan 13 2008 werner.ho@gmx.de
- new version 2.0.0
* Thu Nov 29 2007 werner.ho@gmx.de
- new version 1.0.3
- removed msgstr_size patch
* Wed Feb 28 2007 werner.ho@gmx.de
- added msgstr_size patch
* Tue Aug 29 2006 werner.ho@gmx.de
- added libpng-devel: gkt2-devel of SuSE 9.3 didn't provide it
* Sun Aug 27 2006 werner.ho@gmx.de
- first spec file
